import React from "react";
import { DraftComponent } from "draft-js";
export interface AifBlockLine<T extends string | object> {
    aifid?: string;
    lineType: AifLineType;
    left?: T | null;
    center?: T | null;
    right?: T | null;
    addBelow?: boolean;
    canEdit?: boolean;
    canRemove?: boolean;
    canMove?: boolean;
    canChangeType?: boolean;
}
export const enum AifLineType {
    leftOnly = "Left only",
    centerOnly = "Center only",
    leftAndRight = "Left and Right",
    leftCenterAndRight = "Left, Center and Right"
}
export interface AieStyleMap {
    [styleName: string]: {
        css: React.CSSProperties;
        aieExclude: string[];
    };
}
export const toHtml: (text: string) => string;
export const fromHtml: (text: string) => string;
interface AioIconButtonProps {
    id: string;
    onClick?: (ret: string) => void;
    iconName?: string;
    tipText?: string;
    popUpTip?: boolean;
    menuItems?: string[];
    leftMenuOffset?: string;
    style?: React.CSSProperties;
}
export const AioIconButton: ({ id, onClick, iconName, tipText, popUpTip, menuItems, leftMenuOffset, style, }: AioIconButtonProps) => JSX.Element;
/** Individual options */
export interface AioOption {
    optionName?: AioNewItem;
    type: AioOptionType;
    value: unknown;
    label?: string;
    availableValues?: string[];
    readOnly?: boolean;
}
/** Text replacements, and their replacement matrix */
export interface AioReplacement {
    airid?: string;
    oldText: string;
    newTexts: AioReplacementValues[];
    includeTrailing?: boolean;
    externalName?: string;
}
export interface AioReplacementValues {
    airid?: string;
    texts: string[];
    spaceAfter?: boolean;
    subLists?: AioReplacement[];
}
export interface AioExternalReplacements {
    givenName: string;
    newTexts: AioReplacementValues[];
}
export interface AioExternalSingle {
    airid?: string;
    oldText?: string;
    newText?: string;
}
enum AioOptionType {
    string = "string",
    number = "number",
    array = "array",
    object = "object",
    boolean = "boolean",
    select = "select",
    replacements = "replacements"
}
enum AioNewItem {
    newKey = "newKey",
    newType = "newType"
}
interface AioStringProps {
    id: string;
    label?: string;
    value?: string;
    setValue?: (value: string) => void;
}
export const AioString: (props: AioStringProps) => JSX.Element;
/**
 * Properties for AioReplacements
 * @param value AioReplacement list
 * @param setValue update function
 */
interface AioSingleReplacementProps {
    id: string;
    label?: string;
    replacements?: AioExternalSingle[];
    setReplacements?: (ret: AioExternalSingle[]) => void;
}
/**
 * Option item for replacements
 * @param props replacement object
 * @returns JSX
 */
export const AioSingleReplacements: ({ id, label, replacements, setReplacements, }: AioSingleReplacementProps) => JSX.Element;
interface AioDropSelectProps {
    id: string;
    value?: string;
    availableValues?: Array<string>;
    setValue?: (value: string) => void;
}
/**
 * Wrapper to preprend Icon button with chosen text
 */
export const AioDropSelect: ({ id, value, setValue, availableValues, }: AioDropSelectProps) => JSX.Element;
interface AioReplacementValuesDisplayProps {
    id: string;
    airid?: string;
    texts?: string[];
    spaceAfter?: boolean;
    subLists?: AioReplacement[];
    setReplacementValue?: (ret: AioReplacementValues) => void;
    dontAskSpace?: boolean;
    dontAskTrail?: boolean;
    externalLists?: AioExternalReplacements[];
}
export const AioReplacementValuesDisplay: ({ id, airid, texts, spaceAfter, subLists, setReplacementValue, dontAskSpace, dontAskTrail, externalLists, }: AioReplacementValuesDisplayProps) => JSX.Element;
interface AioReplacmentDisplayProps {
    id: string;
    airid?: string;
    oldText?: string;
    newTexts: AioReplacementValues[];
    includeTrailing?: boolean;
    externalName?: string;
    setReplacement?: (ret: AioReplacement) => void;
    externalLists?: AioExternalReplacements[];
    dontAskSpace?: boolean;
    dontAskTrail?: boolean;
    noText?: boolean;
}
/**
 * Render an individuial AioReplacement
 * @param props value/setValue pair
 */
export const AioReplacementDisplay: ({ id, airid, oldText, newTexts, includeTrailing, externalName, setReplacement, externalLists, dontAskSpace, dontAskTrail, noText: noOldText, }: AioReplacmentDisplayProps) => JSX.Element;
interface AioExpanderProps {
    id: string;
    inputObject?: {
        [key: string]: any;
    };
    label?: string;
    showBorders?: boolean;
    updateObject?: (value: any) => void;
    canAddItems?: boolean;
    canMoveItems?: boolean;
    canRemoveItems?: boolean;
}
export const AioExpander: (props: AioExpanderProps) => JSX.Element;
export interface AitCellData<T extends string | object> {
    aitid?: string;
    text: T;
    justifyText?: DraftComponent.Base.DraftTextAlignment | "decimal" | "default";
    comments?: string;
    colWidth?: number;
    textIndents?: number;
    replacedText?: T;
    spaceAfterRepeat?: boolean;
}
interface AitHeaderCellData<T extends string | object> extends AitCellData<T> {
    colSpan?: number;
    rowSpan?: number;
    repeatColSpan?: number;
    repeatRowSpan?: number;
    spaceAfterSpan?: number;
}
export interface AitRowData<T extends string | object> {
    aitid?: string;
    rowRepeat?: string;
    cells: AitCellData<T>[];
    spaceAfter?: boolean;
}
interface AitHeaderRowData<T extends string | object> extends AitRowData<T> {
    cells: AitHeaderCellData<T>[];
}
export interface AitRowGroupData<T extends string | object> {
    aitid?: string;
    name?: string;
    rows: AitRowData<T>[];
    comments?: string;
    spaceAfter?: boolean;
    replacements?: AioReplacement[];
}
interface AitHeaderGroupData<T extends string | object> extends AitRowGroupData<T> {
    rows: AitHeaderRowData<T>[];
}
export interface AitTableData<T extends string | object> {
    headerData?: AitHeaderGroupData<T> | false;
    bodyData?: AitRowGroupData<T>[];
    comments?: string;
    rowHeaderColumns?: number;
    noRepeatProcessing?: boolean;
    decimalAlignPercent?: number;
}
export const newReplacementValues: () => AioReplacementValues;
export const newExternalReplacements: () => AioExternalReplacements;
export const newExternalSingle: () => AioExternalSingle;
/**
 * Add newRowGroupTemplate to existing body
 * @param l - Length of row
 * @param newRowGroupTemplate
 * @returns New row group
 */
export const newRowGroup: <T extends string | object>(defaultCellWidth: number, l?: number, newRowGroupTemplate?: AitRowGroupData<T>) => AitRowGroupData<T>;
interface oldReplacementText {
    text: string;
    spaceAfter: boolean;
}
interface oldReplacementValue {
    newText: string;
    subList?: oldReplacementValue[];
}
interface oldReplacement {
    airid?: string;
    replacementTexts: oldReplacementText[];
    replacementValues: oldReplacementValue[];
    givenName?: string;
    externalName?: string;
}
export function updateReplacementVersion(reps?: AioReplacement[] | oldReplacement[]): AioReplacement[];
export function updateReplToExtl(reps: AioExternalReplacements[] | oldReplacement[] | {
    name: string;
    list: oldReplacement[];
}[]): AioExternalReplacements[];
interface OldTableData {
    headerData?: OldRowGroupData;
    bodyData?: OldRowGroupData[];
    comments?: string;
    rowHeaderColumns?: number;
    noRepeatProcessing?: boolean;
}
interface OldRowGroupData {
    aitid?: string;
    name?: string;
    rows: AitRowData<string>[];
    comments?: string;
    spaceAfter?: boolean;
    replacements?: AioReplacement[] | oldReplacement[];
}
export const updateTableDataVersion: (inData: OldTableData | AitTableData<string>, defaultCellWidth: number) => AitTableData<string>;
/** Interface for the AsupInternalEditor component */
export interface AsupInternalEditorProps<T extends string | object> {
    id: string;
    value: T;
    setValue?: (ret: T) => void;
    style?: React.CSSProperties;
    styleMap?: AieStyleMap;
    textAlignment?: Draft.DraftComponent.Base.DraftTextAlignment | "decimal" | "default";
    decimalAlignPercent?: number;
    showStyleButtons?: boolean;
    editable?: boolean;
}
export const AsupInternalEditor: <T extends string | object>({ id, value, setValue, style, styleMap, textAlignment, showStyleButtons, editable, decimalAlignPercent, }: AsupInternalEditorProps<T>) => import("react/jsx-runtime").JSX.Element;
interface AsupInternalBlockProps<T extends string | object> {
    id: string;
    lines: AifBlockLine<T>[];
    setLines?: (ret: AifBlockLine<T>[]) => void;
    minLines?: number;
    maxLines?: number;
    externalSingles?: AioExternalSingle[];
    styleMap?: AieStyleMap;
    defaultType?: AifLineType;
    canChangeType?: boolean;
    style?: React.CSSProperties;
    Editor?: (props: AsupInternalEditorProps<T>) => JSX.Element;
    replaceTextInT?: (s: T, oldPhrase: string, newPhrase: string) => T;
}
export const AsupInternalBlock: <T extends string | object>({ id, lines, setLines, minLines, maxLines, externalSingles, styleMap, defaultType, canChangeType, style, Editor, replaceTextInT, }: AsupInternalBlockProps<T>) => JSX.Element;
interface OldBlockLine {
    aifid?: string;
    left?: string | false;
    centre?: string | false;
    right?: string | false;
    addBelow?: boolean;
    canEdit?: boolean;
    canRemove?: boolean;
    canMove?: boolean;
}
export const updateLineDisplayVersion: (inArray: OldBlockLine[] | AifBlockLine<string>[]) => AifBlockLine<string>[];
interface AsupInternalTableProps<T extends string | object> {
    id: string;
    tableData: AitTableData<T>;
    isEditable?: boolean;
    setTableData?: (ret: AitTableData<T>) => void;
    processedDataRef?: React.MutableRefObject<AitTableData<T> | undefined>;
    externalLists?: AioExternalReplacements[];
    externalSingles?: AioExternalSingle[];
    style?: React.CSSProperties;
    showCellBorders?: boolean;
    groupTemplates?: AitRowGroupData<T>[] | false;
    commentStyles?: AieStyleMap;
    cellStyles?: AieStyleMap;
    colWidthMod?: number;
    initialDecimalAlignPercent?: number;
    defaultCellWidth?: number;
    noTableOptions?: boolean;
    Editor?: (props: AsupInternalEditorProps<T>) => JSX.Element;
    getTextFromT?: (text: T) => string[];
    replaceTextInT?: (s: T, oldPhrase: string, newPhrase: string) => T;
}
/**
 * Table view for clinical table data
 * @param props
 * @returns
 */
export const AsupInternalTable: <T extends string | object>({ id, tableData, isEditable, setTableData, processedDataRef, externalLists, externalSingles, style, showCellBorders, groupTemplates, commentStyles, cellStyles, colWidthMod, initialDecimalAlignPercent, defaultCellWidth, noTableOptions, Editor, getTextFromT, replaceTextInT, }: AsupInternalTableProps<T>) => import("react/jsx-runtime").JSX.Element;

//# sourceMappingURL=asupinternalcomponents.d.ts.map
